@@ -1,11 +1,11 @@
 #pragma once
-#define GIT_COMMIT_HASH    "unknown"
-#define GIT_BRANCH         "unknown"
-#define GIT_COMMIT_MESSAGE "unknown"
-#define GIT_COMMIT_DATE    "unknown"
-#define GIT_DIRTY          "unknown"
-#define GIT_TAG            "unknown"
-#define GIT_COMMITS        "0"
+#define GIT_COMMIT_HASH    "967c3c7404d4fa00234e29c70df3e263386d2597"
+#define GIT_BRANCH         "v0.52.1"
+#define GIT_COMMIT_MESSAGE "version: bump to 0.52.1"
+#define GIT_COMMIT_DATE    "Sun Nov 9 23:31:36 2025"
+#define GIT_DIRTY          "clean"
+#define GIT_TAG            "v0.52.1"
+#define GIT_COMMITS        "6564"
 
 #define AQUAMARINE_VERSION "0.9.5"
 // clang-format off
